summaryrefslogtreecommitdiffstats
path: root/kig/misc/calcpaths.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kig/misc/calcpaths.cc')
-rw-r--r--kig/misc/calcpaths.cc48
1 files changed, 24 insertions, 24 deletions
diff --git a/kig/misc/calcpaths.cc b/kig/misc/calcpaths.cc
index 1532715b..55787518 100644
--- a/kig/misc/calcpaths.cc
+++ b/kig/misc/calcpaths.cc
@@ -33,7 +33,7 @@
// I previously misunderstood the semantics of this function
// and thought that the os vector had to be completed with all
// the subtree generated by it. On the contrary, the os vector
-// contains *all* the objects that we want, we only have to
+// tqcontains *all* the objects that we want, we only have to
// reorder them. Now it *should* work, however we postpone
// activating this to a more proper moment
@@ -75,7 +75,7 @@ void localdfs( ObjectCalcer* obj,
std::vector<ObjectCalcer*>& all)
{
visited.push_back( obj );
- const std::vector<ObjectCalcer*> o = obj->children();
+ const std::vector<ObjectCalcer*> o = obj->tqchildren();
for ( std::vector<ObjectCalcer*>::const_iterator i = o.begin(); i != o.end(); ++i )
{
if ( std::find( visited.begin(), visited.end(), *i ) == visited.end() )
@@ -98,7 +98,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
// the general idea here:
// first we build a new Objects variable. For every object in os,
// we put all of its children at the end of it, and we do the same
// for the ones we add..
// "all" is the Objects var we're building...
@@ -115,7 +115,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
{
for ( std::vector<ObjectCalcer*>::const_iterator i = tmp.begin(); i != tmp.end(); ++i )
{
- const std::vector<ObjectCalcer*> o = (*i)->children();
+ const std::vector<ObjectCalcer*> o = (*i)->tqchildren();
std::copy( o.begin(), o.end(), std::back_inserter( all ) );
std::copy( o.begin(), o.end(), std::back_inserter( tmp2 ) );
};
@@ -124,7 +124,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
};
// now we know that if all objects appear at least once after all of
// their parents. So, we take all, and of every object, we remove
// every reference except the last one...
std::vector<ObjectCalcer*> ret;
ret.reserve( os.size() );
@@ -148,7 +148,7 @@ bool addBranch( const std::vector<ObjectCalcer*>& o, const ObjectCalcer* to, std
if ( *i == to )
rb = true;
else
- if ( addBranch( (*i)->children(), to, ret ) )
+ if ( addBranch( (*i)->tqchildren(), to, ret ) )
{
rb = true;
ret.push_back( *i );
@@ -163,7 +163,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& from, con
for ( std::vector<ObjectCalcer*>::const_iterator i = from.begin(); i != from.end(); ++i )
{
- (void) addBranch( (*i)->children(), to, all );
+ (void) addBranch( (*i)->tqchildren(), to, all );
};
std::vector<ObjectCalcer*> ret;
@@ -182,9 +182,9 @@ static void addNonCache( ObjectCalcer* o, std::vector<ObjectCalcer*>& ret )
ret.push_back( o );
else
{
- std::vector<ObjectCalcer*> parents = o->parents();
- for ( uint i = 0; i < parents.size(); ++i )
- addNonCache( parents[i], ret );
+ std::vector<ObjectCalcer*> tqparents = o->tqparents();
+ for ( uint i = 0; i < tqparents.size(); ++i )
+ addNonCache( tqparents[i], ret );
};
}
@@ -193,16 +193,16 @@ static bool visit( const ObjectCalcer* o, const std::vector<ObjectCalcer*>& from
// this function returns true if the visited object depends on one
// of the objects in from. If we encounter objects that are on the
// side of the tree path ( they do not depend on from themselves,
// but their direct children do ), then we add them to ret.
if ( std::find( from.begin(), from.end(), o ) != from.end() ) return true;
- std::vector<bool> deps( o->parents().size(), false );
+ std::vector<bool> deps( o->tqparents().size(), false );
bool somedepend = false;
bool alldepend = true;
- std::vector<ObjectCalcer*> parents = o->parents();
- for ( uint i = 0; i < parents.size(); ++i )
+ std::vector<ObjectCalcer*> tqparents = o->tqparents();
+ for ( uint i = 0; i < tqparents.size(); ++i )
{
- bool v = visit( parents[i], from, ret );
+ bool v = visit( tqparents[i], from, ret );
somedepend |= v;
alldepend &= v;
deps[i] = v;
@@ -211,7 +211,7 @@ static bool visit( const ObjectCalcer* o, const std::vector<ObjectCalcer*>& from
{
for ( uint i = 0; i < deps.size(); ++i )
if ( ! deps[i] )
- addNonCache( parents[i], ret );
+ addNonCache( tqparents[i], ret );
};
return somedepend;
@@ -234,8 +234,8 @@ std::vector<ObjectCalcer*> getAllParents( const std::vector<ObjectCalcer*>& objs
std::set<ObjectCalcer*> next;
for ( std::set<ObjectCalcer*>::const_iterator i = cur.begin(); i != cur.end(); ++i )
{
- std::vector<ObjectCalcer*> parents = (*i)->parents();
- next.insert( parents.begin(), parents.end() );
+ std::vector<ObjectCalcer*> tqparents = (*i)->tqparents();
+ next.insert( tqparents.begin(), tqparents.end() );
};
ret.insert( next.begin(), next.end() );
@@ -253,16 +253,16 @@ std::vector<ObjectCalcer*> getAllParents( ObjectCalcer* obj )
bool isChild( const ObjectCalcer* o, const std::vector<ObjectCalcer*>& os )
{
- std::vector<ObjectCalcer*> parents = o->parents();
- std::set<ObjectCalcer*> cur( parents.begin(), parents.end() );
+ std::vector<ObjectCalcer*> tqparents = o->tqparents();
+ std::set<ObjectCalcer*> cur( tqparents.begin(), tqparents.end() );
while ( ! cur.empty() )
{
std::set<ObjectCalcer*> next;
for ( std::set<ObjectCalcer*>::const_iterator i = cur.begin(); i != cur.end(); ++i )
{
if ( std::find( os.begin(), os.end(), *i ) != os.end() ) return true;
- std::vector<ObjectCalcer*> parents = (*i)->parents();
- next.insert( parents.begin(), parents.end() );
+ std::vector<ObjectCalcer*> tqparents = (*i)->tqparents();
+ next.insert( tqparents.begin(), tqparents.end() );
};
cur = next;
};
@@ -289,8 +289,8 @@ std::set<ObjectCalcer*> getAllChildren( const std::vector<ObjectCalcer*> objs )
i != cur.end(); ++i )
{
ret.insert( *i );
- std::vector<ObjectCalcer*> children = (*i)->children();
- next.insert( children.begin(), children.end() );
+ std::vector<ObjectCalcer*> tqchildren = (*i)->tqchildren();
+ next.insert( tqchildren.begin(), tqchildren.end() );
};
cur = next;
};
@@ -98,7 +98,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
// the general idea here:
// first we build a new Objects variable. For every object in os,
- // we put all of its children at the end of it, and we do the same
+ // we put all of its tqchildren at the end of it, and we do the same
// for the ones we add..
// "all" is the Objects var we're building...
@@ -124,7 +124,7 @@ std::vector<ObjectCalcer*> calcPath( const std::vector<ObjectCalcer*>& os )
};
// now we know that if all objects appear at least once after all of
- // their parents. So, we take all, and of every object, we remove
+ // their tqparents. So, we take all, and of every object, we remove
// every reference except the last one...
std::vector<ObjectCalcer*> ret;
@@ -193,16 +193,16 @@ static bool visit( const ObjectCalcer* o, const std::vector<ObjectCalcer*>& from
// of the objects in from. If we encounter objects that are on the
// side of the tree path ( they do not depend on from themselves,
- // but their direct children do ), then we add them to ret.
+ // but their direct tqchildren do ), then we add them to ret.
if ( std::find( from.begin(), from.end(), o ) != from.end() ) return true;